############################################################
# Author     : Adamson dela Cruz
# Date       : Nov 5, 2017
#
#
# Contains contants for the pricing api
############################################################

# Service
EC2 = 'AmazonEC2'
S3 = 'AmazonS3'
IoT = 'AWSIoT'
RDS = 'AmazonRDS'
LAMBDA = 'AWSLambda'

# Dictionary keys
REGION = 'AWS_REGION'
OFFERS = 'offers'
CURRENT_REGION_INDEX_URL = 'currentRegionIndexUrl'
REGIONS = 'regions'
CURRENT_VERSION_URL = 'currentVersionUrl'

PRODUCT = 'product'
PRODUCTS = 'products'
SKU = 'sku'
ONDEMAND_PRICE = 'ondemand_price'
RESERVED_PRICE = 'reserved_price'
TERMS = 'terms'

ONDEMAND = 'OnDemand'
RESERVED = 'Reserved'
PRICE_DIMENSIONS = 'priceDimensions'
ATTRIBUTES = 'attributes'
INSTANCE_TYPE = 'instanceType'
OPERATING_SYSTEM = 'operatingSystem'

PRICE_PER_UNIT = 'pricePerUnit'
USD = 'USD'
DESCRIPTION = 'description'
